import { DynamoDB, S3 } from 'aws-sdk';
import { v4 as uuid } from 'uuid';
import { withCors } from '../../utils/addingCors';

const dynamoDb = new DynamoDB.DocumentClient();
const s3 = new S3();
const tableName = process.env.TABLE_NAME;
const bucketName = process.env.BUCKET_NAME;
const cloudfrontDomain = process.env.CLOUDFRONT_DOMAIN;

export const handler = async (event: any) => {
  const body = JSON.parse(event.body);

  if (!body.image || !body.name || !body.phone || !body.email) {
    return withCors(400, { error: 'Missing required fields' });
  }

  //create uinque id
  const contactId = uuid();

  // Define S3 object key
  const imageKey = `contacts/${contactId}.jpg`;

  try {
    // Upload image to S3
    const base64Image = body.image.split(',')[1];
    const imageBuffer = Buffer.from(base64Image, 'base64');
    await s3
      .putObject({
        Bucket: bucketName!,
        Key: imageKey,
        Body: imageBuffer,
        ContentType: 'image/jpeg',
      })
      .promise();

    // Build DynamoDB contact object
    const contact = {
      id: contactId,
      name: body.name,
      phone: body.phone,
      email: body.email,
      isFavorite: body.isFavorite || false,
      imageUrl: `https://${cloudfrontDomain}/${imageKey}?timestamp=${Date.now()}`,
    };

    // Store contact in DynamoDB
    await dynamoDb
      .put({
        TableName: tableName!,
        Item: contact,
      })
      .promise();
    return withCors(201, contact);
  } catch (error) {
    console.error(error);
    return withCors(500, { error: 'Could not create contact' });
  }
};
