import * as cdk from 'aws-cdk-lib';
import * as cognito from 'aws-cdk-lib/aws-cognito';

//CognitoService
export class AuthenticationStack extends cdk.Stack {
  public readonly userPool: cognito.UserPool;
  public readonly userPoolClient: cognito.UserPoolClient;

  constructor(scope: cdk.App, id: string, props?: cdk.StackProps) {
    super(scope, id, props);

    this.userPool = new cognito.UserPool(this, 'ContactsAppUserPool', {
      selfSignUpEnabled: true,
      signInAliases: { email: true },
      autoVerify: { email: true },
      userPoolName: 'ContactsAppUserPool',
    });
    //This make visible UserPoolId in Cloud Formation Output
    new cdk.CfnOutput(this, 'ContactsAppUserPoolId', {
      value: this.userPool.userPoolId,
    });

    this.userPoolClient = new cognito.UserPoolClient(
      this,
      'ContactsAppUserPoolClient',
      {
        userPoolClientName: 'ContactAppUserPoolClient',
        userPool: this.userPool,
        authFlows: { userPassword: true },
      }
    );

    //This make visible UserPoolClientId in Cloud Formation Output
    new cdk.CfnOutput(this, 'ContactsAppUserPoolClientId', {
      value: this.userPoolClient.userPoolClientId,
    });

    cdk.Tags.of(this.userPool).add('Service', 'Auth');
  }
}
