import { useState } from 'react';
import Card from '@mui/material/Card';
import { DataGrid } from '@mui/x-data-grid';
import { useLocation, useNavigate } from 'react-router-dom';

import Page from 'components/Page';
import DataGridToolbar from 'components/DataGridToolbar';
import useContactsColumns from './useContactsColumns';

import useConfirmDialog from 'hooks/useConfirmDialog';
import { CONTACTS_ROUTES } from 'routes/paths';
import {
  useDeleteContactMutation,
  useGetContactsQuery,
} from 'storeSlices/apiSlice';
import { useAppSelector } from 'hooks/storeHooks';

export default function AllContacts() {
  const { pathname } = useLocation();
  const [pageSize, setPageSize] = useState<number>(5);
  const [selectedIds, setSelectedIds] = useState<string[]>([]);
  const jwtToken = useAppSelector((state) => state.auth.tokens?.idToken);

  const { data, isLoading } = useGetContactsQuery(jwtToken);
  const [deleteOneContact] = useDeleteContactMutation();

  const [getConfirmation, Confirmation] = useConfirmDialog();
  const navigate = useNavigate();

  /*   function filterContacts() {
    const parts = pathname.split("/");
    const urlTarget = parts[parts.length - 1];
    if (urlTarget === "all") {
      return mockedContacts;
    } else if (urlTarget === "favorites") {
      const favoriteContacts = mockedContacts.filter(
        (contact) => contact.isFavorite === true
      );
      return favoriteContacts;
    } else {
      const filteredContactsByLabel = mockedContacts.filter((contact) =>
        contact.labels.some((label) => label.labelName === urlTarget)
      );
      return filteredContactsByLabel;
    }
  } */

  const handleBatchDelete = () => {
    console.log('handleBatchDelete', selectedIds);
  };

  const handleFavorite = (_id: string) => {
    console.log('handleFavorite', _id);
  };

  const handleEdit = (id: string) => {
    navigate(`${CONTACTS_ROUTES.edit}/${id}`);
  };
  const handleDelete = async (id: string) => {
    const isConfirmed = await getConfirmation({
      title: 'Delete contact',
      contentText: 'Are you sure you want to delete this contact?',
      confirmLabel: `Delete`,
    });
    isConfirmed && deleteOneContact(id);
  };

  const columns = useContactsColumns({
    handleFavorite,
    handleDelete,
    handleEdit,
  });

  return (
    <Page title='All contacts'>
      <Card sx={{ m: 5 }}>
        <DataGrid
          pageSize={pageSize}
          onPageSizeChange={(newPageSize: number) => setPageSize(newPageSize)}
          rowsPerPageOptions={[5, 10, 20, 50, 100]}
          initialState={{
            sorting: { sortModel: [{ field: 'name', sort: 'asc' }] },
          }}
          rows={data || []}
          columns={columns}
          loading={isLoading}
          getRowId={(row) => row.id}
          components={{ Toolbar: DataGridToolbar }}
          componentsProps={{
            toolbar: {
              numSelected: selectedIds.length,
              onDelete: handleBatchDelete,
            },
          }}
          onSelectionModelChange={(ids) => setSelectedIds(ids as string[])}
          disableExtendRowFullWidth={true}
        />
        <Confirmation />
      </Card>
    </Page>
  );
}
